#ifndef COMPATIBILITYWINDOW_H
#define COMPATIBILITYWINDOW_H

#include <QMainWindow>
#include <QtGui>
#include <QtWebKit>
#include <qwebviewselectionsuppressor.h>
#ifdef Q_WS_MAEMO_5
    #include <QtGui/qabstractkineticscroller.h>
#endif
#include <QDebug>

namespace Ui {
    class CompatibilityWindow;
}

class CompatibilityWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit CompatibilityWindow(QWidget *parent = 0);
    ~CompatibilityWindow();
public slots:


private:
    Ui::CompatibilityWindow *ui;
    QWebView *view;
    QWebViewSelectionSuppressor *suppressor;

private slots:
    void setButtonIcons();
    void zoomIn();
    void zoomOut();
};

#endif // COMPATIBILITYWINDOW_H
